@@ -3,7 +3,8 @@ function (form, k) {
     av <- all.vars(form)
     factors <- sum(av %in% c("z1", "z2"))
     cf <- paste(form[3])
-    form. <- paste(" ~ ", paste("z", 1:factors, collapse = " + ", sep = ""), " + ", cf)
+    #form. <- paste(" ~ ", paste("z", 1:factors, collapse = " + ", sep = ""), " + ", cf)
+    form. <- paste(" ~ ", cf)
     form. <- as.formula(form.)
     GH <- gauher(k)
     grid.t <- expand.grid(lapply(1:factors, function (k, u) u$x, u = GH))
