@@ -1,4 +1,4 @@
-`observedFreqs` <-
+observedFreqs <-
 function (object, Y) {
     if (!class(object) %in% c("grm", "gpcm", "ltm", "rasch", "tpm"))
         stop("'object' must inherit from either class 'grm', class 'gpcm', class 'ltm', class 'rasch' or class 'tpm'.\n")
